@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+import inspect
+import warnings
 from django.db import models
 from django.db.models import fields
 from django.db.models.fields import related
@@ -431,11 +433,22 @@ class AutoFixtureBase(object):
                 recalc_fields.extend(e.fields)
         return recalc_fields
 
-    def post_process_instance(self, instance):
+    def post_process_instance(self, instance, commit):
         '''
-        Overwrite this method to modify the created *instance* at the last
-        possible moment. It gets the generated *instance* and must return the
-        modified instance.
+        Overwrite this method to modify the created *instance* before it gets
+        returned by the :meth:`create` or :meth:`create_one`.
+        It gets the generated *instance* and must return the modified
+        instance. The *commit* parameter indicates the *commit* value that the
+        user passed into the :meth:`create` method. It defaults to ``True``
+        and should be respected, which means if it is set to ``False``, the
+        *instance* should not be saved.
+        '''
+        return instance
+
+    def pre_process_instance(self, instance):
+        '''
+        Same as :meth:`post_process_instance`, but it is being called before
+        saving an *instance*.
         '''
         return instance
 
@@ -445,6 +458,12 @@ class AutoFixtureBase(object):
         instance will not be saved and many to many relations will not be
         processed.
 
+        Subclasses that override ``create_one`` can specify arbitrary keyword
+        arguments. They will be passed through by the
+        :meth:`autofixture.base.AutoFixture.create` method and the helper
+        functions :func:`autofixture.create` and
+        :func:`autofixture.create_one`.
+
         May raise :exc:`CreateInstanceError` if constraints are not satisfied.
         '''
         tries = self.tries
@@ -466,6 +485,9 @@ class AutoFixtureBase(object):
                     self.tries,
                     ', '.join([field.name for field in process]),
             ))
+
+        instance = self.pre_process_instance(instance)
+
         if commit:
             instance.save()
 
@@ -480,9 +502,17 @@ class AutoFixtureBase(object):
             model=self.model,
             instance=instance,
             committed=commit)
-        return self.post_process_instance(instance)
 
-    def create(self, count=1, commit=True):
+        post_process_kwargs = {}
+        if 'commit' in inspect.getargspec(self.post_process_instance).args:
+            post_process_kwargs['commit'] = commit
+        else:
+            warnings.warn(
+                "Subclasses of AutoFixture need to provide a `commit` "
+                "argument for post_process_instance methods", DeprecationWarning)
+        return self.post_process_instance(instance, **post_process_kwargs)
+
+    def create(self, count=1, commit=True, **kwargs):
         '''
         Create and return ``count`` model instances. If *commit* is ``False``
         the instances will not be saved and many to many relations will not be
@@ -494,7 +524,7 @@ class AutoFixtureBase(object):
         '''
         object_list = []
         for i in range(count):
-            instance = self.create_one(commit=commit)
+            instance = self.create_one(commit=commit, **kwargs)
             object_list.append(instance)
         return object_list
 
