@@ -152,7 +152,7 @@ class LoremGenerator(Generator):
                 paras = ['<p>%s</p>' % p for p in paras]
             lorem = u'\n\n'.join(paras)
         if self.max_length:
-            length = random.randint(self.max_length / 10, self.max_length)
+            length = random.randint(round(self.max_length / 10), self.max_length)
             lorem = lorem[:max(1, length)]
         return lorem.strip()
 
@@ -314,7 +314,7 @@ class FirstNameGenerator(Generator):
         'Michael', 'Mark', 'Paul', 'Peter', 'Phillip', 'Stephen', 'Tony',
         'Titus', 'Trevor', 'Timothy', 'Victor', 'Vincent', 'Winston', 'Walt']
     female = [
-        'Abbie', 'Anna', 'Alice', 'Beth', 'Carrie', 'Christina' 'Danielle',
+        'Abbie', 'Anna', 'Alice', 'Beth', 'Carrie', 'Christina', 'Danielle',
         'Emma', 'Emily', 'Esther', 'Felicia', 'Grace', 'Gloria', 'Helen',
         'Irene', 'Joanne', 'Joyce', 'Jessica', 'Kathy', 'Katie', 'Kelly',
         'Linda', 'Lydia', 'Mandy', 'Mary', 'Olivia', 'Priscilla',
